summaryrefslogtreecommitdiff
path: root/chart2/source/view/main/ChartView.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'chart2/source/view/main/ChartView.cxx')
-rw-r--r--chart2/source/view/main/ChartView.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/chart2/source/view/main/ChartView.cxx b/chart2/source/view/main/ChartView.cxx
index 1750879eaef0..9297cef1b779 100644
--- a/chart2/source/view/main/ChartView.cxx
+++ b/chart2/source/view/main/ChartView.cxx
@@ -443,7 +443,7 @@ VCoordinateSystem* lcl_getCooSysForPlotter( const std::vector< VCoordinateSystem
return 0;
}
-typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is the dimension, second index is the axis index that indicates wether this is a main or secondary axis
+typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is the dimension, second index is the axis index that indicates whether this is a main or secondary axis
typedef std::pair< VCoordinateSystem* , tFullAxisIndex > tFullCoordinateSystem;
typedef std::map< VCoordinateSystem*, tFullAxisIndex > tCoordinateSystemMap;
@@ -1881,7 +1881,7 @@ awt::Rectangle ExplicitValueProvider::addAxisTitleSizes(
ExplicitValueProvider* pExplicitValueProvider = ExplicitValueProvider::getExplicitValueProvider(xChartView);
if( pExplicitValueProvider )
{
//detect wether x axis points into x direction or not
if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( xChartModel ) ) )
{
std::swap( xTitle_Height, xTitle_Width );
@@ -1948,7 +1948,7 @@ awt::Rectangle ExplicitValueProvider::substractAxisTitleSizes(
ExplicitValueProvider* pExplicitValueProvider = ExplicitValueProvider::getExplicitValueProvider(xChartView);
if( pExplicitValueProvider )
{
//detect wether x axis points into x direction or not
if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( xChartModel ) ) )
{
std::swap( xTitle_Height, xTitle_Width );
@@ -2046,7 +2046,7 @@ bool getAvailablePosAndSizeForDiagram(
chart2::RelativePosition aRelativePosition;
if( xProp.is() && (xProp->getPropertyValue( C2U( "RelativePosition" ) )>>=aRelativePosition) )
{
//@todo decide wether x is primary or secondary
//the coordinates re relative to the page
double fX = aRelativePosition.Primary*rPageSize.Width;
@@ -2178,7 +2178,7 @@ std::auto_ptr<VTitle> lcl_createTitle( TitleHelper::eTitleType eType
{
rbAutoPosition = false;
//@todo decide wether x is primary or secondary
double fX = aRelativePosition.Primary*rPageSize.Width;
double fY = aRelativePosition.Secondary*rPageSize.Height;
@@ -1881,7 +1881,7 @@ awt::Rectangle ExplicitValueProvider::addAxisTitleSizes(
if( pExplicitValueProvider )
{
- //detect wether x axis points into x direction or not
+ //detect whether x axis points into x direction or not
if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( xChartModel ) ) )
{
@@ -1948,7 +1948,7 @@ awt::Rectangle ExplicitValueProvider::substractAxisTitleSizes(
if( pExplicitValueProvider )
{
- //detect wether x axis points into x direction or not
+ //detect whether x axis points into x direction or not
if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( xChartModel ) ) )
{
@@ -2046,7 +2046,7 @@ bool getAvailablePosAndSizeForDiagram(
if( xProp.is() && (xProp->getPropertyValue( C2U( "RelativePosition" ) )>>=aRelativePosition) )
{
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
//the coordinates re relative to the page
double fX = aRelativePosition.Primary*rPageSize.Width;
@@ -2178,7 +2178,7 @@ std::auto_ptr<VTitle> lcl_createTitle( TitleHelper::eTitleType eType
{
rbAutoPosition = false;
- //@todo decide wether x is primary or secondary
+ //@todo decide whether x is primary or secondary
double fX = aRelativePosition.Primary*rPageSize.Width;
double fY = aRelativePosition.Secondary*rPageSize.Height;